@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 
 import java.io.FileOutputStream;
@@ -22,6 +24,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.TreeMap;
 import java.util.jar.JarOutputStream;
 import java.util.zip.ZipEntry;
@@ -178,7 +181,7 @@ public class Package {
                 clName = clName.substring(0, clName.length() - JavaClass.EXTENSION.length());
             }
             clName = Utility.packageToPath(clName);
-            try (final InputStream inputStream = classPath.getInputStream(clName)) {
+            try (InputStream inputStream = classPath.getInputStream(clName)) {
                 clazz = new ClassParser(inputStream, clName).parse();
             }
             // here we create the root set of classes to process
@@ -199,7 +202,7 @@ public class Package {
             final String name = dependents.firstKey();
             final String from = dependents.remove(name);
             if (allClasses.get(name) == null) {
-                try (final InputStream inputStream = classPath.getInputStream(name)) {
+                try (InputStream inputStream = classPath.getInputStream(name)) {
                     clazz = new ClassParser(inputStream, name).parse();
                     addDependents(clazz);
                 } catch (final IOException e) {
@@ -214,12 +217,12 @@ public class Package {
         }
 
         // create the jar
-        try (final JarOutputStream jarFile = new JarOutputStream(new FileOutputStream(defaultJar))) {
+        try (JarOutputStream jarFile = new JarOutputStream(new FileOutputStream(defaultJar))) {
             jarFile.setLevel(5); // use compression
             int written = 0;
-            for (final String name : allClasses.keySet()) { // add entries for every class
-                final JavaClass claz = allClasses.get(name);
-                final ZipEntry zipEntry = new ZipEntry(name + JavaClass.EXTENSION);
+            for (final Entry<String, JavaClass> entry : allClasses.entrySet()) { // add entries for every class
+                final JavaClass claz = allClasses.get(entry.getKey());
+                final ZipEntry zipEntry = new ZipEntry(entry.getValue() + JavaClass.EXTENSION);
                 final byte[] bytes = claz.getBytes();
                 final int length = bytes.length;
                 jarFile.putNextEntry(zipEntry);
