@@ -1,18 +1,20 @@
-/**
- *  Licensed to the Apache Software Foundation (ASF) under one or more
- *  contributor license agreements.  See the NOTICE file distributed with
- *  this work for additional information regarding copyright ownership.
- *  The ASF licenses this file to You under the Apache License, Version 2.0
- *  (the "License"); you may not use this file except in compliance with
- *  the License.  You may obtain a copy of the License at
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 
 package org.apache.bcel.classfile;
@@ -25,6 +27,7 @@ import java.util.Iterator;
 import java.util.stream.Stream;
 
 import org.apache.bcel.Const;
+import org.apache.bcel.util.Args;
 
 // The new table is used when generic types are about...
 
@@ -59,22 +62,23 @@ import org.apache.bcel.Const;
  */
 public class LocalVariableTypeTable extends Attribute implements Iterable<LocalVariable> {
 
+    private static final LocalVariable[] EMPTY_ARRAY = {};
+
     private LocalVariable[] localVariableTypeTable; // variables
 
     LocalVariableTypeTable(final int nameIdx, final int len, final DataInput input, final ConstantPool cpool) throws IOException {
         this(nameIdx, len, (LocalVariable[]) null, cpool);
-
         final int localVariableTypeTableLength = input.readUnsignedShort();
         localVariableTypeTable = new LocalVariable[localVariableTypeTableLength];
-
         for (int i = 0; i < localVariableTypeTableLength; i++) {
             localVariableTypeTable[i] = new LocalVariable(input, cpool);
         }
     }
 
-    public LocalVariableTypeTable(final int nameIndex, final int length, final LocalVariable[] localVariableTable, final ConstantPool constantPool) {
+    public LocalVariableTypeTable(final int nameIndex, final int length, final LocalVariable[] localVariableTypeTable, final ConstantPool constantPool) {
         super(Const.ATTR_LOCAL_VARIABLE_TYPE_TABLE, nameIndex, length, constantPool);
-        this.localVariableTypeTable = localVariableTable;
+        this.localVariableTypeTable = localVariableTypeTable != null ? localVariableTypeTable : LocalVariable.EMPTY_ARRAY;
+        Args.requireU2(this.localVariableTypeTable.length, "localVariableTypeTable.length");
     }
 
     public LocalVariableTypeTable(final LocalVariableTypeTable c) {
@@ -92,7 +96,6 @@ public class LocalVariableTypeTable extends Attribute implements Iterable<LocalV
     @Override
     public Attribute copy(final ConstantPool constantPool) {
         final LocalVariableTypeTable c = (LocalVariableTypeTable) clone();
-
         c.localVariableTypeTable = new LocalVariable[localVariableTypeTable.length];
         Arrays.setAll(c.localVariableTypeTable, i -> localVariableTypeTable[i].copy());
         c.setConstantPool(constantPool);
@@ -114,7 +117,6 @@ public class LocalVariableTypeTable extends Attribute implements Iterable<LocalV
                 return variable;
             }
         }
-
         return null;
     }
 
@@ -132,7 +134,7 @@ public class LocalVariableTypeTable extends Attribute implements Iterable<LocalV
     }
 
     public final void setLocalVariableTable(final LocalVariable[] localVariableTable) {
-        this.localVariableTypeTable = localVariableTable;
+        this.localVariableTypeTable = localVariableTable != null ? localVariableTable : EMPTY_ARRAY;
     }
 
     /**
@@ -141,15 +143,12 @@ public class LocalVariableTypeTable extends Attribute implements Iterable<LocalV
     @Override
     public final String toString() {
         final StringBuilder buf = new StringBuilder();
-
         for (int i = 0; i < localVariableTypeTable.length; i++) {
             buf.append(localVariableTypeTable[i].toStringShared(true));
-
             if (i < localVariableTypeTable.length - 1) {
                 buf.append('\n');
             }
         }
-
         return buf.toString();
     }
 }
