@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.bcel.verifier.statics;
 
@@ -118,7 +120,9 @@ public final class Pass3aVerifier extends PassVerifier {
         /** The ConstantPoolGen instance this Visitor operates on. */
         private final ConstantPoolGen constantPoolGen;
 
-        /** The only Constructor. */
+        /**
+         * Constructs a new instance.
+         */
         InstOperandConstraintVisitor(final ConstantPoolGen constantPoolGen) {
             this.constantPoolGen = constantPoolGen;
         }
@@ -250,7 +254,7 @@ public final class Pass3aVerifier extends PassVerifier {
                 final int dimensions = ((ArrayType) t).getDimensions();
                 if (dimensions > Const.MAX_ARRAY_DIMENSIONS) {
                     constraintViolated(o,
-                        "Not allowed to create an array with more than " + Const.MAX_ARRAY_DIMENSIONS + " dimensions;" + " actual: " + dimensions);
+                        "Not allowed to create an array with more than " + Const.MAX_ARRAY_DIMENSIONS + " dimensions; actual: " + dimensions);
                 }
             }
         }
@@ -608,8 +612,8 @@ public final class Pass3aVerifier extends PassVerifier {
                 // INVOKEVIRTUAL is an InvokeInstruction, the argument and return types are resolved/verified,
                 // too. So are the allowed method names.
                 final String className = o.getClassName(constantPoolGen);
-                JavaClass jc;
-                if (className.charAt(0) == '[') { // array type, e.g. invoke can be someArray.clone()
+                final JavaClass jc;
+                if (className.charAt(0) == '[') { // array type, for example invoke can be someArray.clone()
                     jc = Repository.lookupClass("java.lang.Object");
                 } else {
                     jc = Repository.lookupClass(className);
@@ -922,7 +926,7 @@ public final class Pass3aVerifier extends PassVerifier {
                     if (instructionPosition == offset) {
                         if (offsets.contains(offset)) {
                             addMessage("LineNumberTable attribute '" + code.getLineNumberTable() + "' refers to the same code offset ('" + offset
-                                + "') more than once" + " which is violating the semantics [but is sometimes produced by IBM's 'jikes' compiler].");
+                                + "') more than once which is violating the semantics [but is sometimes produced by IBM's 'jikes' compiler].");
                         } else {
                             offsets.add(offset);
                         }
@@ -1043,8 +1047,7 @@ public final class Pass3aVerifier extends PassVerifier {
                 try {
                     delayedPass2Checks();
                 } catch (final ClassConstraintException | ClassFormatException cce) {
-                    vr = new VerificationResult(VerificationResult.VERIFIED_REJECTED, cce.getMessage());
-                    return vr;
+                    return new VerificationResult(VerificationResult.VERIFIED_REJECTED, cce.getMessage());
                 }
                 try {
                     pass3StaticInstructionChecks();
@@ -1124,7 +1127,7 @@ public final class Pass3aVerifier extends PassVerifier {
         final Instruction last = instructionList.getEnd().getInstruction();
         if (!(last instanceof ReturnInstruction || last instanceof RET || last instanceof GotoInstruction || last instanceof ATHROW)) {
             throw new StaticCodeInstructionConstraintException(
-                "Execution must not fall off the bottom of the code array." + " This constraint is enforced statically as some existing verifiers do"
+                "Execution must not fall off the bottom of the code array. This constraint is enforced statically as some existing verifiers do"
                     + " - so it may be a false alarm if the last instruction is not reachable.");
         }
     }
@@ -1196,9 +1199,7 @@ public final class Pass3aVerifier extends PassVerifier {
         String ret;
         try {
             ret = obj.toString();
-        }
-
-        catch (final RuntimeException e) {
+        } catch (final RuntimeException e) {
             // including ClassFormatException, trying to convert the "signature" of a ReturnaddressType LocalVariable
             // (shouldn't occur, but people do crazy things)
             String s = obj.getClass().getName();
