@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.bcel.verifier.structurals;
 
@@ -20,6 +22,7 @@ import org.apache.bcel.Const;
 import org.apache.bcel.classfile.Constant;
 import org.apache.bcel.classfile.ConstantClass;
 import org.apache.bcel.classfile.ConstantDouble;
+import org.apache.bcel.classfile.ConstantDynamic;
 import org.apache.bcel.classfile.ConstantFloat;
 import org.apache.bcel.classfile.ConstantInteger;
 import org.apache.bcel.classfile.ConstantLong;
@@ -40,7 +43,7 @@ import org.apache.bcel.generic.*;
  * are two Type.INT on top of the stack). Monitor-specific behavior is not simulated.
  * </p>
  *
- * <b>Conventions:</b>
+ * <strong>Conventions:</strong>
  *
  * <p>
  * Type.VOID will never be pushed onto the stack. Type.DOUBLE and Type.LONG that would normally take up two stack slots
@@ -70,7 +73,7 @@ public class ExecutionVisitor extends EmptyVisitor {
     private ConstantPoolGen cpg;
 
     /**
-     * Constructor. Constructs a new instance of this class.
+     * Constructs a new instance of this class.
      */
     public ExecutionVisitor() {
     }
@@ -112,11 +115,11 @@ public class ExecutionVisitor extends EmptyVisitor {
 
     /// ** Symbolically executes the corresponding Java Virtual Machine instruction. */
     // public void visitWIDE(WIDE o) {
-    // The WIDE instruction is modelled as a flag
+    // The WIDE instruction is modeled as a flag
     // of the embedded instructions in BCEL.
     // Therefore BCEL checks for possible errors
     // when parsing in the .class file: We don't
-    // have even the possibilty to care for WIDE
+    // have even the possibility to care for WIDE
     // here.
     // }
 
@@ -124,12 +127,11 @@ public class ExecutionVisitor extends EmptyVisitor {
     @Override
     public void visitAALOAD(final AALOAD o) {
         stack().pop(); // pop the index int
-//System.out.print(stack().peek());
+        // System.out.print(stack().peek());
         final Type t = stack().pop(); // Pop Array type
         if (t == Type.NULL) {
             stack().push(Type.NULL);
-        } // Do nothing stackwise --- a NullPointerException is thrown at Run-Time
-        else {
+        } else {
             final ArrayType at = (ArrayType) t;
             stack().push(at.getElementType());
         }
@@ -433,7 +435,6 @@ public class ExecutionVisitor extends EmptyVisitor {
                 stack().push(v);
             }
             stack().push(u);
-            stack().push(t);
         } else { // t.getSize() is 1
             final Type u = stack().pop();
             final Type v = stack().pop();
@@ -448,8 +449,8 @@ public class ExecutionVisitor extends EmptyVisitor {
             }
             stack().push(v);
             stack().push(u);
-            stack().push(t);
         }
+        stack().push(t);
     }
 
     /** Symbolically executes the corresponding Java Virtual Machine instruction. */
@@ -1054,6 +1055,9 @@ public class ExecutionVisitor extends EmptyVisitor {
         if (c instanceof ConstantClass) {
             stack().push(Type.CLASS);
         }
+        if (c instanceof ConstantDynamic) {
+            stack().push(Type.OBJECT);
+        }
     }
 
     /** Symbolically executes the corresponding Java Virtual Machine instruction. */
