@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.bcel.verifier.structurals;
 
@@ -55,7 +57,7 @@ import org.apache.bcel.verifier.exc.VerifierConstraintViolatedException;
 public final class Pass3bVerifier extends PassVerifier {
     /*
      * TODO: Throughout pass 3b, upper halves of LONG and DOUBLE are represented by Type.UNKNOWN. This should be changed in
-     * favour of LONG_Upper and DOUBLE_Upper as in pass 2.
+     * favor of LONG_Upper and DOUBLE_Upper as in pass 2.
      */
 
     /**
@@ -168,8 +170,8 @@ public final class Pass3bVerifier extends PassVerifier {
 
         // LOOP!
         while (!icq.isEmpty()) {
-            InstructionContext u;
-            ArrayList<InstructionContext> ec;
+            final InstructionContext u;
+            final ArrayList<InstructionContext> ec;
             if (!DEBUG) {
                 final int r = random.nextInt(icq.size());
                 u = icq.getIC(r);
@@ -228,7 +230,7 @@ public final class Pass3bVerifier extends PassVerifier {
                     final ArrayList<InstructionContext> newchainClone = (ArrayList<InstructionContext>) newchain.clone();
                     icq.add(theSuccessor, newchainClone);
                 }
-            } else {// "not a ret"
+            } else { // "not a ret"
 
                 // Normal successors. Add them to the queue of successors.
                 final InstructionContext[] succs = u.getSuccessors();
@@ -256,7 +258,7 @@ public final class Pass3bVerifier extends PassVerifier {
                 // by using an empty chain for the exception handlers.
                 // if (v.execute(new Frame(u.getOutFrame(oldchain).getLocals(),
                 // new OperandStack (u.getOutFrame().getStack().maxStack(),
-                // (exc_hds[s].getExceptionType()==null? Type.THROWABLE : exc_hds[s].getExceptionType())) ), newchain), icv, ev) {
+                // (exc_hds[s].getExceptionType() == null ? Type.THROWABLE : exc_hds[s].getExceptionType())) ), newchain), icv, ev) {
                 // icq.add(v, (ArrayList) newchain.clone());
                 if (v.execute(new Frame(u.getOutFrame(oldchain).getLocals(), new OperandStack(u.getOutFrame(oldchain).getStack().maxStack(),
                     excHd.getExceptionType() == null ? Type.THROWABLE : excHd.getExceptionType())), new ArrayList<>(), icv, ev)) {
@@ -276,14 +278,14 @@ public final class Pass3bVerifier extends PassVerifier {
                 final LocalVariables lvs = f.getLocals();
                 for (int i = 0; i < lvs.maxLocals(); i++) {
                     if (lvs.get(i) instanceof UninitializedObjectType) {
-                        this.addMessage("Warning: ReturnInstruction '" + ic + "' may leave method with an uninitialized object in the local variables array '"
+                        addMessage("Warning: ReturnInstruction '" + ic + "' may leave method with an uninitialized object in the local variables array '"
                             + lvs + "'.");
                     }
                 }
                 final OperandStack os = f.getStack();
                 for (int i = 0; i < os.size(); i++) {
                     if (os.peek(i) instanceof UninitializedObjectType) {
-                        this.addMessage(
+                        addMessage(
                             "Warning: ReturnInstruction '" + ic + "' may leave method with an uninitialized object on the operand stack '" + os + "'.");
                     }
                 }
@@ -331,7 +333,7 @@ public final class Pass3bVerifier extends PassVerifier {
 
         // Pass 3a ran before, so it's safe to assume the JavaClass object is
         // in the BCEL repository.
-        JavaClass jc;
+        final JavaClass jc;
         try {
             jc = Repository.lookupClass(myOwner.getClassName());
         } catch (final ClassNotFoundException e) {
